import React from 'react';
import '../../css/style.css';
import * as d3 from "d3";

class Repartitionventes extends React.Component {

  constructor(props){
    super(props);
    this.ref = React.createRef();

    this.createPie = d3.pie().value(d => d.value).sort(null);
    this.createArc = d3.arc().innerRadius(props.innerRadius).outerRadius(props.outerRadius);
    this.colors = d3.scaleOrdinal(d3.schemeCategory10);
    this.format = d3.format(".2f");

    this.state = {
      data: [],
      year : 2015
    }
  }

  getData(){
    fetch(`https://${document.domain}:8443/repartition-ventes/${this.state.year}`)
      .then(response => {
        if (response.ok) {
          return response.json();
        } else {
          throw new Error('error');
        }
      })
      .then(data => {
        this.setState({data: data });
        console.log(data);
        this.drawPieChart(data);
      })
      .catch(error => console.log("error"));
  }

  componentDidMount(){
    this.getData();
  }


  drawPieChart(datas){
    const svg = d3.select(this.ref.current);
    const data = this.createPie(datas);
    const { width, height, innerRadius, outerRadius } = this.props;

    svg.attr("class", "chart").attr("width", width).attr("height", height);
    const group = svg.append("g").attr("tranform",`translate(${outerRadius} ${outerRadius})`);
    const groupWithEnter = group.selectAll("g.arc").data(data).enter();

    const path = groupWithEnter.append("g").attr("class","arc");
    path.append("path").attr("class","arc").attr("d", this.createArc).attr("fill", (d,i) => this.colors(d.index));
    path.append("text").attr("text-anchor","middle").attr("alignment-baseline","middle")
      .attr("transform", d => `translate(${this.createArc.centroid(d)}`).style("fill","white")
      .style("font-size, 10").text(d => this.format(d.value));
  }

  render() {
    console.log("coucou")
    console.log(this.state.data)
    return (
      <div>
        <h1>Le nom du graph {this.state.year}</h1>
        <svg ref={this.ref} />
      </div>
    )
  }
}

export default Repartitionventes;



